@@ -3,11 +3,7 @@
 """Tests PFS-related functionality"""
 
 import pytest
-import random
-import string
-import threading
 from io import BytesIO
-from collections import namedtuple
 
 import python_pachyderm
 from tests import util
@@ -61,7 +57,7 @@ def test_start_commit():
     commit = client.start_commit(repo_name, None)
     assert commit.repo.name == repo_name
 
-    with pytest.raises(Exception):
+    with pytest.raises(python_pachyderm.RpcError):
         client.start_commit("some-fake-repo", "master")
 
 def test_start_commit_with_parent_no_branch():
@@ -129,7 +125,7 @@ def test_commit_context_mgr():
     with client.commit(repo_name, None) as c2:
         pass
 
-    with pytest.raises(Exception):
+    with pytest.raises(python_pachyderm.RpcError):
         with client.commit("some-fake-repo", "master"):
             pass
 
@@ -257,7 +253,8 @@ def test_inspect_commit():
         client.put_file_bytes(c, 'input.json', b'hello world')
 
     commit = client.inspect_commit("{}/master".format(repo_name))
-    assert commit.branch.name == "master"
+    if util.test_pachyderm_version() >= (1, 9, 0):
+        assert commit.branch.name == "master"
     assert commit.finished
     assert commit.description == ""
     assert commit.size_bytes == 11
@@ -284,8 +281,9 @@ def test_subscribe_commit():
         pass
 
     commit = next(commits)
-    assert commit.branch.repo.name == repo_name
-    assert commit.branch.name == "master"
+    if util.test_pachyderm_version() >= (1, 9, 0):
+        assert commit.branch.repo.name == repo_name
+        assert commit.branch.name == "master"
 
 def test_list_branch():
     client, repo_name = sandbox("list_branch")
@@ -402,4 +400,27 @@ def test_inspect_branch():
     client, repo_name = sandbox("inspect_branch")
     client.create_branch(repo_name, "foobar")
     branch = client.inspect_branch(repo_name, "foobar")
-    print(branch)
+    assert branch.branch.name == "foobar"
+
+@util.skip_if_below_pachyderm_version(1, 9, 7)
+def test_fsck():
+    client = python_pachyderm.Client()
+    assert len(list(client.fsck())) == 0
+
+def test_diff_file():
+    client, repo_name = sandbox("diff_file")
+
+    with client.commit(repo_name, "master") as old_commit:
+        client.put_file_bytes(old_commit, 'file1.dat', BytesIO(b'old data 1'))
+        client.put_file_bytes(old_commit, 'file2.dat', BytesIO(b'old data 2'))
+
+    with client.commit(repo_name, "master") as new_commit:
+        client.put_file_bytes(new_commit, 'file1.dat', BytesIO(b'new data 1'))
+
+    diff = client.diff_file(new_commit, "file1.dat", old_commit, "file2.dat")
+    assert diff.new_files[0].file.path == "file1.dat"
+    assert diff.old_files[0].file.path == "file2.dat"
+
+    diff = client.diff_file(new_commit, "file1.dat")
+    assert diff.new_files[0].file.path == "file1.dat"
+    assert diff.old_files[0].file.path == "file1.dat"
